st_truchet_dissolve: Dissolving the boundaries of individual tiles in Truchet...

View source: R/st_truchet_dissolve.R

st_truchet_dissolveR Documentation

Dissolving the boundaries of individual tiles in Truchet mosaics

Description

Dissolving the boundaries of individual tiles in Truchet mosaics

Usage

st_truchet_dissolve(mosaic)

Arguments

mosaic

a mosaic produced by function st_truchet_ms

Value

An object of type sf with the mosaic after dissolving the boundaries of individual tiles

Examples

mosaic <- st_truchet_ms()
mosaic <- st_truchet_dissolve(mosaic)

paezha/truchet documentation built on April 27, 2022, 9:53 a.m.