st_truchet_l: Truchet tiles made with polygons

View source: R/st_truchet_l.R

st_truchet_lR Documentation

Truchet tiles made with polygons

Description

Truchet tiles made with polygons

Usage

st_truchet_l(x = 0, y = 0, type = "dl")

Arguments

x

A number with the x coordinate of the center of the tile

y

A number with the y coordinate of the center of the tile

type

A single character to designate a type of tile; currently supported options are "dl", "dr"

Value

A list with one or more objects of type sf representing one or more tiles depending on type

Note

For a discussion of Truchet patterns see http://arearugscarpet.blogspot.com/2014/04/the-curse-of-truchets-tiles.html

Examples

st_truchet_l(type = "dl")
st_truchet_l(type = "dr")

paezha/truchet documentation built on April 27, 2022, 9:53 a.m.