st_truchet_p: Truchet tiles made with polygons

View source: R/st_truchet_p.R

st_truchet_pR Documentation

Truchet tiles made with polygons

Description

Truchet tiles made with polygons

Usage

st_truchet_p(x = 0, y = 0, type = "dl", scale_p = 1)

Arguments

x

A number with the x coordinate of the center of the tile

y

A number with the y coordinate of the center of the tile

type

A single character to designate a type of tile; currently supported options are "dl", "dr", "-", "|", "+.", "+", "x.", "tn", "fnw", "fne", "fsw", "fse", "ane", "asw"

scale_p

A number to designate the scale of the tile; currently supported options are 1, 1/2, and 1/4

Value

A list with one or more objects of type sf representing one or more tiles depending on type

Note

For a discussion of multi-scale Truchet patterns see https://christophercarlson.com/portfolio/multi-scale-truchet-patterns/

Examples

st_truchet_p(type = "-")
st_truchet_p(type = "fnw", scale_p = 1/2)

paezha/truchet documentation built on April 27, 2022, 9:53 a.m.