View source: R/st_truchet_dissolve.R
| st_truchet_dissolve | R Documentation |
Dissolving the boundaries of individual tiles in Truchet mosaics
st_truchet_dissolve(mosaic)
mosaic |
a mosaic produced by function |
An object of type sf with the mosaic after dissolving the boundaries of individual tiles
mosaic <- st_truchet_ms() mosaic <- st_truchet_dissolve(mosaic)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.