st_truchet_flex: Flexible Truchet tiles

View source: R/st_truchet_flex.R

st_truchet_flexR Documentation

Flexible Truchet tiles

Description

Flexible Truchet tiles

Usage

st_truchet_flex(x = 0, y = 0, type = "Al", b = 1/2)

Arguments

x

A number with the x coordinate of the center of the tile

y

A number with the y coordinate of the center of the tile

type

A single character to designate a type of tile; currently supported options are "Ac", "Bc", "Cc", "Dc", "As", "Bs", "Cs", "Ds"

b

A number between zero and one that controls the shape of the boundary between the two parts of the tile

Value

A list with one or more objects of type sf representing one or more tiles depending on type

Note

For a discussion of Truchet patterns see: Robert Bosch & Urchin Colley (2013) Figurative mosaics from flexible Truchet tiles, Journal of Mathematics and the Arts, 7:3-4, 122-135, 10.1080/17513472.2013.838830

Examples

st_truchet_flex(type = "Al")
st_truchet_flex(type = "Cl")

paezha/truchet documentation built on April 27, 2022, 9:53 a.m.