View source: R/st_truchet_flex.R
| st_truchet_flex | R Documentation |
Flexible Truchet tiles
st_truchet_flex(x = 0, y = 0, type = "Al", b = 1/2)
x |
A number with the x coordinate of the center of the tile |
y |
A number with the y coordinate of the center of the tile |
type |
A single character to designate a type of tile; currently supported options are "Ac", "Bc", "Cc", "Dc", "As", "Bs", "Cs", "Ds" |
b |
A number between zero and one that controls the shape of the boundary between the two parts of the tile |
A list with one or more objects of type sf representing one or more tiles depending on type
For a discussion of Truchet patterns see: Robert Bosch & Urchin Colley (2013) Figurative mosaics from flexible Truchet tiles, Journal of Mathematics and the Arts, 7:3-4, 122-135, 10.1080/17513472.2013.838830
st_truchet_flex(type = "Al") st_truchet_flex(type = "Cl")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.