| st_truchet_l | R Documentation |
Truchet tiles made with polygons
st_truchet_l(x = 0, y = 0, type = "dl")
x |
A number with the x coordinate of the center of the tile |
y |
A number with the y coordinate of the center of the tile |
type |
A single character to designate a type of tile; currently supported options are "dl", "dr" |
A list with one or more objects of type sf representing one or more tiles depending on type
For a discussion of Truchet patterns see http://arearugscarpet.blogspot.com/2014/04/the-curse-of-truchets-tiles.html
st_truchet_l(type = "dl") st_truchet_l(type = "dr")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.