| st_truchet_p | R Documentation |
Truchet tiles made with polygons
st_truchet_p(x = 0, y = 0, type = "dl", scale_p = 1)
x |
A number with the x coordinate of the center of the tile |
y |
A number with the y coordinate of the center of the tile |
type |
A single character to designate a type of tile; currently supported options are "dl", "dr", "-", "|", "+.", "+", "x.", "tn", "fnw", "fne", "fsw", "fse", "ane", "asw" |
scale_p |
A number to designate the scale of the tile; currently supported options are 1, 1/2, and 1/4 |
A list with one or more objects of type sf representing one or more tiles depending on type
For a discussion of multi-scale Truchet patterns see https://christophercarlson.com/portfolio/multi-scale-truchet-patterns/
st_truchet_p(type = "-") st_truchet_p(type = "fnw", scale_p = 1/2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.